@@ -16,7 +16,6 @@ LOGGER = logging.getLogger(__name__)
 
 class CloudFormationLintRule(object):
     """CloudFormation linter rules"""
-
     id = ''
     shortdesc = ''
     description = ''
@@ -35,6 +34,16 @@ class CloudFormationLintRule(object):
     def __repr__(self):
         return '%s: %s' % (self.id, self.shortdesc)
 
+    @property
+    def severity(self):
+        """Severity level"""
+        levels = {
+            'I': 'informational',
+            'E': 'error',
+            'W': 'warning',
+        }
+        return levels.get(self.id[0].upper(), 'unknown')
+
     def verbose(self):
         """Verbose output"""
         return '%s: %s\n%s' % (self.id, self.shortdesc, self.description)
