@@ -37,9 +37,10 @@ class AllowedValue(CloudFormationLintRule):
             if '{{resolve:' not in str(value):
                 # Always compare the allowed value as a string, strict typing is not of concern for this rule
                 if str(value) not in allowed_value_specs:
-                    message = 'You must specify a valid value for {0} ({1}).\nValid values are {2}'
+                    message = 'You must specify a valid value for {0} ({1}).\n{2}'
+                    description = 'Valid values are {0}'.format(json.dumps(allowed_value_specs))
                     matches.append(RuleMatch(path, message.format(
-                        property_name, value, json.dumps(allowed_value_specs))))
+                        property_name, value, description)))
 
         return matches
 
