@@ -89,6 +89,21 @@ class Template(object):  # pylint: disable=R0904
 
         return parameters
 
+    def get_modules(self):
+        """Get Modules"""
+        LOGGER.debug('Get modules from template...')
+        resources = self.template.get('Resources', {})
+        if not resources:
+            return {}
+
+        results = {}
+        for k, v in resources.items():
+            if isinstance(v, dict):
+                if v.get('Type') is not None and str(v.get('Type')).endswith('::MODULE'):
+                    results[k] = v
+
+        return results
+
     def get_mappings(self):
         """Get Resources"""
         LOGGER.debug('Get mapping from template...')
@@ -123,7 +138,7 @@ class Template(object):  # pylint: disable=R0904
     def get_valid_refs(self):
         """Get all valid Refs"""
         LOGGER.debug('Get all valid REFs from template...')
-        results = {}
+        results = cfnlint.helpers.RegexDict()
         parameters = self.template.get('Parameters', {})
         if parameters:
             for name, value in parameters.items():
@@ -135,9 +150,15 @@ class Template(object):  # pylint: disable=R0904
         resources = self.template.get('Resources', {})
         if resources:
             for name, value in resources.items():
-                if 'Type' in value:
+                resource_type = value.get('Type', '')
+                if resource_type.endswith('::MODULE'):
                     element = {}
-                    element['Type'] = value['Type']
+                    element['Type'] = 'MODULE'
+                    element['From'] = 'Resources'
+                    results['{}.*'.format(name)] = element
+                elif resource_type:
+                    element = {}
+                    element['Type'] = resource_type
                     element['From'] = 'Resources'
                     results[name] = element
 
@@ -166,20 +187,21 @@ class Template(object):  # pylint: disable=R0904
         for name, value in resources.items():
             if 'Type' in value:
                 valtype = value['Type']
-                if valtype.startswith(astrik_string_types):
-                    LOGGER.debug('Cant build an appropriate getatt list from %s', valtype)
-                    results[name] = {'*': {'PrimitiveItemType': 'String'}}
-                elif valtype.startswith(astrik_unknown_types):
-                    LOGGER.debug('Cant build an appropriate getatt list from %s', valtype)
-                    results[name] = {'*': {}}
-                else:
-                    if value['Type'] in resourcetypes:
-                        if 'Attributes' in resourcetypes[valtype]:
-                            results[name] = {}
-                            for attname, attvalue in resourcetypes[valtype]['Attributes'].items():
-                                element = {}
-                                element.update(attvalue)
-                                results[name][attname] = element
+                if isinstance(valtype, six.string_types):
+                    if valtype.startswith(astrik_string_types):
+                        LOGGER.debug('Cant build an appropriate getatt list from %s', valtype)
+                        results[name] = {'*': {'PrimitiveItemType': 'String'}}
+                    elif valtype.startswith(astrik_unknown_types) or valtype.endswith('::MODULE'):
+                        LOGGER.debug('Cant build an appropriate getatt list from %s', valtype)
+                        results[name] = {'*': {}}
+                    else:
+                        if value['Type'] in resourcetypes:
+                            if 'Attributes' in resourcetypes[valtype]:
+                                results[name] = {}
+                                for attname, attvalue in resourcetypes[valtype]['Attributes'].items():
+                                    element = {}
+                                    element.update(attvalue)
+                                    results[name][attname] = element
 
         return results
 
